# Genesis Foundation Utils

The `@genesislcap/foundation-utils` package provides a collection of utility services and helpers designed to facilitate common development tasks within Genesis applications. It aims to enhance productivity by offering reusable solutions for patterns and problems encountered across different projects.

## API Documentation

For more detailed information on API and configurations, please refer to the [API documentation](docs/api/index.md) in the `docs/api` directory.

## Features

The library encompasses a broad range of features, including:

- **[Data](src/data/README.md)** - Manages in-memory databases and data storage solutions.
- **[Decorators](src/decorators/README.md)** - Provides decorators for enhancing class functionalities, such as rendering on change.
- **[Design System](src/design-system/README.md)** - Holds the design system configurations and utilities.
- **[Directives](src/directives/README.md)** - Offers Angular-like directives for DOM manipulations, including conditional rendering and synchronization functionalities.
- **[ENV](src/env/README.md)** - Contains utilities for environment variable management and detection of development environments.
- **[Error](src/error/README.md)** - Deals with error mapping and handling strategies.
- **[Formatters](src/formatters/README.md)** - Includes functions for formatting dates and numbers according to locale settings.
- **[Logger](src/logger/README.md)** - A simple logging utility for debugging and information tracking.
- **[Mappers](src/mappers/README.md)** - Focuses on data transformation, especially for DTOs (Data Transfer Objects).
- **[Mixins](src/mixins/README.md)** - Provides mixins for common functionalities like lifecycle hooks and state management.
- **[Observer](src/observer/README.md)** - Implements the Observer pattern for reactive programming.
- **[Resource](src/observer/README.md)** - Defines types and interfaces for resource management.
- **[Serializers](src/serializers/README.md)** - Contains serializers, particularly for JSON data handling.
- **[State](src/state/README.md)** - Manages reactive state and provides utilities for state observation.
- **[Styles](src/styles/README.md)** - Includes utilities for styling, dealing with colors, typography, and DOM styles.
- **[UUID](src/uuid/README.md)** - Utilities for generating and managing UUIDs.
- **[Window](src/window/README.md)** - Provides abstractions and utilities for window object manipulations.

## Installation

To include `@genesislcap/foundation-utils` in your project, add it as a dependency in your `package.json` file and follow your project's routine for dependency installation.

```json
{
  "dependencies": {
    "@genesislcap/foundation-utils": "latest"
  }
}
```

## License

Note: this project provides front-end dependencies and uses licensed components listed in the next section; thus, licenses for those components are required during development. Contact [Genesis Global](https://genesis.global/contact-us/) for more details.

### Licensed components

Genesis low-code platform
