/**
 * The sub-path used for WebSocket connections when API_HOST is not set
 * @public
 * @defaultValue `'gwf'`
 * @remarks Optional.
 * @example
 * If `API_HOST` is not set, `SOCKET_EXT` is set to `/custom` and UI is served on `https://localhost:1234`
 * API host URL will be `wss://localhost:1234/custom`
 */
declare let _SOCKET_EXT: string;
export { _SOCKET_EXT as SOCKET_EXT };
/**
 * The path to a JSON config file for the HTTP mode.
 * @remarks Optional.
 * @public
 */
declare let _FORCE_HTTP: string;
export { _FORCE_HTTP as FORCE_HTTP };
/**
 * Genesis Socket URL
 * @remarks
 * Built from the current {@link https://developer.mozilla.org/en-US/docs/Web/API/Location} object and {@link SOCKET_EXT | socket extension}.
 * @example
 * ```ts
 * await this.connect.connect(GENESIS_SOCKET_URL); // < wss://localhost:6060/gwf/
 * ```
 * @public
 */
export declare const GENESIS_SOCKET_URL: string;
/**
 * The Genesis Server URL (WebSocket or HTTP).
 * @remarks Optional.
 * @defaultValue `${PROTOCOL}//${location.host}/${_SOCKET_EXT}/`
 * @example ws://localhost/gwf/, ws://localhost:9064
 * @public
 */
declare let _API_HOST: string;
export { _API_HOST as API_HOST };
/**
 * Configuration settings for HTTP, used in http connect flow [`genesislcap-foundation-comms.HttpConnectConfig`](https://link-to-docs).
 * @remarks Optional.
 * @public
 */
declare let _HTTP_CONFIG: string;
export { _HTTP_CONFIG as HTTP_CONFIG };
/**
 * The default Organisation value, used in auth/login flow [`genesislcap-foundation-login`](https://link-to-docs).
 * @remarks Optional.
 * @public
 */
declare let _DEFAULT_ORGANISATION: string;
export { _DEFAULT_ORGANISATION as DEFAULT_ORGANISATION };
/**
 * The default Password value, used in auth/login flow [`genesislcap-foundation-login`](https://link-to-docs).
 * @remarks Optional.
 * @public
 */
declare let _DEFAULT_PASSWORD: string;
export { _DEFAULT_PASSWORD as DEFAULT_PASSWORD };
/**
 * The default Username value, used in auth/login flow [`genesislcap-foundation-login`](https://link-to-docs).
 * @remarks Optional.
 * @public
 */
declare let _DEFAULT_USER: string;
export { _DEFAULT_USER as DEFAULT_USER };
//# sourceMappingURL=variables.d.ts.map