/**
 * Converts a plain object to a reactive, observable object.
 *
 * @privateRemarks
 * Code borrowed from fast-element v2. We can remove post upgrade.
 *
 * @example
 * An array or reactive items.
 * ```ts
 * this.todos = todosResponse.map((t) => reactive(t));
 * ```
 *
 * @example
 * Add item.
 * ```ts
 * add(description: string) {
 *    this.splice(this.todos.length, 0, reactive({ description, done: false }));
 * }
 * ```
 *
 * @example
 * Remove item.
 * ```ts
 * remove(todo: Todo) {
 *    const index = this.todos.indexOf(todo);
 *    index !== -1 && this.splice(index, 1);
 * }
 *```
 *
 * @param object - The object to make reactive.
 * @param deep - Indicates whether to deeply convert the object.
 * @returns The converted object.
 *
 * @beta
 */
export declare function reactive<T>(object: T, deep?: boolean): T;
//# sourceMappingURL=reactive.d.ts.map