const isoDateSliceEnd = 10;
/**
 * Formats [DATE] UNIX Timestamps (without time) to readable strings
 * @public
 */
export function formatDateTimestamp(timestamp) {
    if (!timestamp || isNaN(timestamp))
        return null;
    return new Date(timestamp).toISOString().slice(0, isoDateSliceEnd);
}
const isoDateTimeSliceEnd = 19;
/**
 * Formats [DATETIME] UNIX Timestamps (with time) to readable strings
 * @public
 */
export function formatDateTimeTimestamp(timestamp) {
    if (!timestamp || isNaN(timestamp))
        return null;
    return new Date(timestamp).toISOString().slice(0, isoDateTimeSliceEnd).replace('T', ' ');
}
/**
 * Formats [DATE|DATETIME] Unix Timestamps to readable strings
 * @public
 * @param timestamp - The UNIX Timestamp.
 * @param withTime - The flag to determine if formatted value should contain 'time' info.
 */
export function formatTimestamp(timestamp, withTime) {
    if (withTime) {
        return formatDateTimeTimestamp(timestamp);
    }
    return formatDateTimestamp(timestamp);
}
const defaultDateOptions = {
    year: 'numeric',
    month: '2-digit',
    day: '2-digit',
    timeZone: 'UTC',
};
/**
 * @public
 */
export function getDateFormatter(locale = 'en-GB', options = defaultDateOptions) {
    return (params) => {
        if (!(params && typeof params.value === 'number'))
            return '';
        return new Intl.DateTimeFormat(locale, options).format(params.value);
    };
}
