/**
 * Resolve a promise after a timeout.
 *
 * @example
 * ```ts
 * const result = await Promise.race([
 *  resourceChecks(sourceRef, resource),
 *  resolveAfter<MonitoredResourceChecksResult>(this.config.checkTimeout, () => ({
 *    isConnected: false,
 *    lastUpdated: Date.now(),
 *   })),
 * ]);
 * ```
 *
 * @public
 */
export const resolveAfter = (ms, valueCreator) => {
    return new Promise((resolve) => {
        setTimeout(() => {
            resolve(valueCreator());
        }, ms);
    });
};
