function shouldTraverse(value, traversed) {
    return value !== null && value !== void 0 && typeof value === 'object' && !traversed.has(value);
}
/**
 * Visit object utility.
 *
 * @privateRemarks
 * Code borrowed from fast-element v2. We can remove post upgrade.
 *
 * @example
 * Reactive example.
 * ```ts
 * export function reactive<T>(object: T, deep = false): T {
 *   visitObject(object, deep, makeObserverVisitor, void 0, observed);
 *   return object;
 * }
 * ```
 *
 * @param object - The object.
 * @param deep - A flag to indicate if a recursive visit of sub objects should occur.
 * @param visitor - The defined {@link ObjectVisitor} logic.
 * @param data - Visitor data.
 * @param traversed - The traversed object set.
 *
 * @beta
 */
export function visitObject(object, deep, visitor, data, traversed) {
    if (!shouldTraverse(object, traversed)) {
        return;
    }
    traversed.add(object);
    if (Array.isArray(object)) {
        visitor.visitArray(object, data);
        for (const item of object) {
            visitObject(item, deep, visitor, data, traversed);
        }
    }
    else {
        visitor.visitObject(object, data);
        for (const key in object) {
            /**
             * Added this hasOwnProperty guard
             */
            if (object.hasOwnProperty(key)) {
                const value = object[key];
                visitor.visitProperty(object, key, value, data);
                if (deep) {
                    visitObject(value, deep, visitor, data, traversed);
                }
            }
        }
    }
}
